@@ -46,15 +46,6 @@ static Mouse_Handle * mhandle_first;
 static Mouse_Handle * mhandle_last;
 static Mouse_Handle * mhandle_current;
 
-/* Screen area mouse handles */
-/* XXX: These handlers should live elsewhere */
-static Mouse_Handle * main_win_mhandle;
-static Mouse_Handle * other_buttons_mhandle;
-static Mouse_Handle * market_cb_mhandle;
-static Mouse_Handle * help_mhandle;
-static Mouse_Handle * loadsave_mhandle;
-
-
 /* ---------------------------------------------------------------------- *
  * cs_mouse_handler
  * --
@@ -69,7 +60,6 @@ void
 cs_mouse_handler (int enc_button, int dx, int dy)
 {
     int x, y;
-    int group = 0;
     int button = enc_button & ~LC_MOUSE_RELEASE & ~LC_MOUSE_PRESS;
     int button_pressed = enc_button & LC_MOUSE_PRESS;
     int button_released = enc_button & LC_MOUSE_RELEASE;
@@ -468,35 +458,38 @@ do_mouse_main_win (int px, int py, int button)
     Rect* mw = &scr.main_win;
     int size;
     int x, y; /* mappoint */
+    int mod_x, mod_y; /* upper left coords of module clicked on */
+    int mps_result;
 
     if (button == LC_MOUSE_MIDDLEBUTTON)
 	return;
 
     pixel_to_mappoint(px, py, &x, &y);
 
+    if (MP_TYPE(x,y) == CST_USED) {
+	mod_x = MP_INFO(x,y).int_1;
+	mod_y = MP_INFO(x,y).int_2;
+    } else {
+	mod_x = x;
+	mod_y = y;
+    }
+
     /* Bring up mappoint_stats for any right mouse click */
+    /* XXX: Environmental (right click) MPS should show the clicked 
+       square, not the master square */
     if (button == LC_MOUSE_RIGHTBUTTON) {
-	if (MP_TYPE(x,y) == CST_USED) {
-	    mappoint_stats (MP_INFO(x,y).int_1, MP_INFO(x,y).int_2, button);
-	} else {
-	    mappoint_stats (x, y, button);
-	}
+	mps_set(mod_x, mod_y, MPS_ENV);
 	return;
     }
 
     /* Check rocket launches */
+    /* XXX: put this in modules/rocket.c */
+    /* XXX: wait for second click to ask for launch */
     if (button == LC_MOUSE_LEFTBUTTON) {
-        int xx, yy;
-	if (MP_TYPE(x,y) == CST_USED) {
-	    xx = MP_INFO(x,y).int_1;
-            yy = MP_INFO(x,y).int_2;
-        } else {
-	  xx = x;
-	  yy = y;
-	}
-	if (MP_TYPE(xx,yy) >= CST_ROCKET_5 && MP_TYPE(xx,yy) <= CST_ROCKET_7) {
-	  if (ask_launch_rocket_click (xx,yy)) {
-	    launch_rocket (xx, yy);
+	if (MP_TYPE(mod_x,mod_y) >= CST_ROCKET_5 && 
+	    MP_TYPE(mod_x,mod_y) <= CST_ROCKET_7) {
+	  if (ask_launch_rocket_click (mod_x,mod_y)) {
+	    launch_rocket (mod_x, mod_y);
 	  }
 	}
     }
@@ -507,7 +500,8 @@ do_mouse_main_win (int px, int py, int button)
 	if (mt_draw (px, py, MT_START)) {
 	    /* We need to set mps to current location, since the user might 
 	       click on the transport to see the mps */
-	    mappoint_stats (x, y, button);
+
+	    mps_set(mod_x, mod_y, MPS_MAP);
 	    return;
 	}
     }
@@ -519,11 +513,21 @@ do_mouse_main_win (int px, int py, int button)
     }
 
     /* Bring up mappoint_stats for certain left mouse clicks */
+    /* XXX: Need to check market and port double-clicks here */
     if (MP_TYPE(x,y) != CST_GREEN) {
-	if (MP_TYPE(x,y) == CST_USED) {
-	    mappoint_stats (MP_INFO(x,y).int_1, MP_INFO(x,y).int_2, button);
-	} else {
-	    mappoint_stats (x, y, button);
+	mps_result = mps_set(mod_x, mod_y, MPS_MAP);
+
+	if (mps_result >= 1) {
+	    if (MP_GROUP(mod_x,mod_y) == GROUP_MARKET)
+	    {
+		clicked_market_cb (mod_x, mod_y);
+		return;
+	    }
+	    else if (MP_GROUP(mod_x,mod_y) == GROUP_PORT)
+	    {
+		clicked_port_cb (mod_x, mod_y);
+		return;
+	    }
 	}
 	return;
     }
@@ -671,6 +675,8 @@ do_mouse_other_buttons (int x, int y, int button)
 	window_results ();
     }
 
+    /* XXX: WCK: This is broken; should be a mouse handler in 
+       mps.c anyway */
     /* Advance mps screen if clicked on */
     else if (mouse_in_rect (&scr.mappoint_stats,x,y)) {
 	if (button == LC_MOUSE_RIGHTBUTTON) {
@@ -687,8 +693,7 @@ do_mouse_other_buttons (int x, int y, int button)
 	    }
 	    return;
 	}
-	advance_mps_style ();
-	refresh_mps ();
+	mps_global_advance();
     }
 
    /* Advance monthgraph screen if clicked on */
@@ -789,6 +794,7 @@ check_bulldoze_area (int x, int y)
     bulldoze_item (xx,yy);
 }
 
+/* XXX: mouse.c?  wtf! */
 void
 fire_area (int x, int y)
 {
@@ -808,7 +814,6 @@ fire_area (int x, int y)
 void 
 drag_screen (void) 
 {
-    Rect* mw = &scr.main_win;
     int cur_mappoint_x = 0;
     int cur_mappoint_y = 0;
 
@@ -839,13 +844,9 @@ drag_screen (void)
 void
 do_market_cb_template (int x, int y, int is_market_cb)
 {
-    int old_flags = MP_INFO(mcbx,mcby).flags;
     Rect* mcb = &scr.market_cb;
     int is_sell;
 
-    static Mouse_Handle * checkbox_mhandle;
-    static Mouse_Handle * omni_mhandle;
-
     hide_mouse ();
     if (!mouse_in_rect(mcb,x,y)) {
 	if (is_market_cb) {
@@ -1230,7 +1231,7 @@ mt_draw (int cxp, int cyp, int flag) /* c[xy]p are pixel coordinates */
 	    draw_main_window_box (green (8)); 
 	    status_message(0,0);
 	}
-	else if (draw_ret = do_mt_draw(ox, cx, oy, cy, mt_perm)) {
+	else if ((draw_ret = do_mt_draw(ox, cx, oy, cy, mt_perm))) {
 
 	    print_total_money ();
 	    mt_flag = 0;
